===============
django-inviter2
===============

.. image:: https://travis-ci.org/mjschultz/django-inviter2.svg?branch=master
    :target: https://travis-ci.org/mjschultz/django-inviter2
    :alt: Build status

.. image:: https://coveralls.io/repos/mjschultz/django-inviter2/badge.png?branch=master
    :target: https://coveralls.io/r/mjschultz/django-inviter2?branch=master
    :alt: Coverage status

Let your users invite new users.

Useful if you want your webapp to be in a private beta mode or for only permitting access to known users.

Installation
============

    $ pip install django-inviter2

Version Support
===============

We try to maintain support at or near Django's `supported versions`_.
Though we've dropped support for Python 3.2 (file an issue if you need it!).

- Django 1.7 (requires Python 2.7, 3.3, or 3.4)
- Django 1.8 (requires Python 2.7, 3.3, 3.4, or 3.5)
- Django 1.9 (requires Python 2.7, 3.4, or 3.5)

.. _supported versions: https://www.djangoproject.com/download/

History
=======

This is a fork of django-inviter_.

.. _django-inviter: http://www.caffeinehit.com/work/code/django-inviter


Documentation is available via `Read the Docs`_

.. _Read the Docs: http://django-inviter2.readthedocs.org/
